Library API Documentation — dbilib - v0.5.0 Documentation

# Library API Documentation

The page contains the low-level documentation for each of the importable modules in `dbilib`.

In addition to the documentation, most of the public methods come with one or more usage examples and access to the source code itself.

Links to module-level documentation

- database - Public database interface
- _dbi_base - Private base module for all database interfaces
- _dbi_mssql - Private database interface for MS SQL Server
- _dbi_mysql - Private database interface for MySQL and MariaDB
- _dbi_oracle - Private database interface for Oracle
- _dbi_sqlite - Private database interface for SQLite